@@ -6,5 +6,5 @@ from __future__ import absolute_import
 from hubspot.crm.quotes.api.associations_api import AssociationsApi
 from hubspot.crm.quotes.api.basic_api import BasicApi
 from hubspot.crm.quotes.api.batch_api import BatchApi
+from hubspot.crm.quotes.api.public_object_api import PublicObjectApi
 from hubspot.crm.quotes.api.search_api import SearchApi
-from hubspot.crm.quotes.api.default_api import DefaultApi
